@@ -102,7 +102,7 @@ main (int argc, char **argv)
         setlocale (LC_ALL, "");
 
         error = NULL;
-        context = gupnp_context_new (NULL, NULL, 0, &error);
+        context = g_initable_new (GUPNP_TYPE_CONTEXT, NULL, &error, NULL);
         if (error) {
                 g_printerr ("Error creating the GUPnP context: %s\n",
 			    error->message);
